@@ -6,7 +6,6 @@ from datetime import datetime
 
 from airless.config import get_config
 from airless.dto.pubsub_to_bq import PubsubToBqDto
-from airless.hook.google.pubsub import PubsubHook
 from airless.operator.base import BaseEventOperator
 
 
@@ -15,8 +14,6 @@ class ErrorReprocessOperator(BaseEventOperator):
     def __init__(self):
         super().__init__()
 
-        self.pubsub_hook = PubsubHook()
-
     def execute(self, data, topic):
 
         input_type = data['input_type']
@@ -46,6 +43,8 @@ class ErrorReprocessOperator(BaseEventOperator):
                 to_table=get_config('BIGQUERY_TABLE_ERROR'),
                 to_schema=None,
                 to_partition_column='_created_at',
+                to_extract_to_cols=False,
+                to_keys_format=None,
                 data=data)
             self.pubsub_hook.publish(
                 project=get_config('GCP_PROJECT'),
@@ -65,7 +64,7 @@ class ErrorReprocessOperator(BaseEventOperator):
             'sender': get_config('EMAIL_SENDER_ERROR'),
             'recipients': eval(get_config('EMAIL_RECIPIENTS_ERROR')),
             'subject': f'{origin} | {message_id}',
-            'content': f'Input Type: {data["input_type"]} Origin: {origin}\nMessage ID: {message_id} {json.dumps(data["data"])}\n\n{data["error"]}'
+            'content': f'Input Type: {data["input_type"]} Origin: {origin}\nMessage ID: {message_id}\n\n {json.dumps(data["data"])}\n\n{data["error"]}'
         }
         self.pubsub_hook.publish(
             project=get_config('GCP_PROJECT'),
